; *****************************************************
; *** Chinook Demo - 11-Aug-2007 by Kevin Krausnick ***
; ***    Ported to Acme Assembler on 14-Sep-2024    ***
; *****************************************************

SCREENRAM = $0400
VIC       = $D000
SID       = $D400
COLORRAM  = $D800
GETIN     = $FFE4
CLRSCR    = $E544
EXTCOL    = 53280
BGCOL0    = 53281
TIME      = 162

* = 2049

;CREDITS - "10 SYS2082:REM BY KEVIN KRAUSNICK"
!BYTE 32,8,10,0,158,50,48,56,50,58,143,32,66,89,32,75
!BYTE 69,86,73,78,32,75,82,65,85,83,78,73,67,75,0,0,0

JSR CHARSINRAM  ;USE PROGRAMMABLE CHARACTER FOR STARS IN SKY
JSR DRAWSCREEN  ;RENDER AIRPORT
JSR SPRITEINIT  ;INITIALIZE SPRITES
JSR SOUNDINIT   ;INITIALIZE SOUND
JSR STARTUP     ;STARTING ENGINES
JSR ANIMATE     ;TAXI, TAKEOFF AND CRUISE
JSR CLEANUP     ;PREPARE TO EXIT
RTS             ;EXIT PROGRAM

;USE PROGRAMMABLE CHARACTERS FOR TEXT-BASED GRAPHICS
CHARSINRAM = *
LDA 56334
AND #254
STA 56334       ;TURN OFF KEYSCAN INTERRUPT TIMER
LDA 1
AND #251
STA 1           ;SWITCH IN CHARACTER
LDY #0
L16 LDA 53248,Y
STA 8192,Y
LDA 53248+256,Y
STA 8192+256,Y
LDA 53248+512,Y
STA 8192+512,Y
LDA 53248+768,Y
STA 8192+768,Y
LDA 53248+1024,Y
STA 8192+1024,Y
LDA 53248+1280,Y
STA 8192+1280,Y
LDA 53248+1536,Y
STA 8192+1536,Y
LDA 53248+1792,Y
STA 8192+1792,Y
DEY
BNE L16
LDA 1
ORA #4
STA 1           ;SWITCH IN I/O
LDA 56334
ORA #1
STA 56334       ;RESTART KEYSCAN INTERRUPT TIMER
LDA 53272
AND #240
ORA #8
STA 53272       ;ACTIVATE RAM CHARACTER SET

LDY #0          ;MAP CUSTOM CHARACTERS
L17 LDA CUSTCHARS,Y
STA 8192+200,Y
INY
CPY #56
BNE L17
LDA #0
STA RADARFRAME
JSR SPINRADAR
RTS

; *** RENDER AIRPORT ***
DRAWSCREEN = *
LDA #11
STA EXTCOL
LDA #0
STA BGCOL0

LDY #0
L0 = *
LDA SCREENDATA,Y
STA SCREENRAM,Y
LDA SCREENDATA+256,Y
STA SCREENRAM+256,Y
LDA SCREENDATA+512,Y
STA SCREENRAM+512,Y
LDA SCREENDATA+768,Y
STA SCREENRAM+768,Y

LDA COLORDATA,Y
STA COLORRAM,Y
LDA COLORDATA+256,Y
STA COLORRAM+256,Y
LDA COLORDATA+512,Y
STA COLORRAM+512,Y
LDA COLORDATA+768,Y
STA COLORRAM+768,Y
INY
BNE L0
RTS

; *** INITIALIZE SPRITES ***
SPRITEINIT = *
LDX #46   ;2944 / 64 = 46
LDY #0
L1 = *
TXA
STA 2040,Y ;SPRITE OFFSET IN MEMORY
INX
INY
CPY #8
BNE L1

LDA #20      ;INITIALIZE VARIABLES
STA HELIX1
LDA #44
STA HELIX2
LDA #%00111100
STA HELIXHI
LDA #215
STA HELIY
LDA #0
STA KEYPRESS
STA LIFTOFF
LDA #30
STA STARTDELAY
STA PITCH

LDA #100
STA VIC     ;SPRITE 0 (PARKED - LEFT SIDE) X LOCATION
LDA #124
STA VIC+2   ;SPRITE 1 (PARKED - RIGHT SIDE) X LOCATION
LDA HELIX1  ;LEFT SIDE OF HELICOPTER
STA VIC+4   ;SPRITE 2 (ROTORS OUT - LEFT SIDE) X LOCATION
STA VIC+8   ;SPRITE 4 (ROTORS IN - LEFT SIDE) X LOCATION
LDA HELIX2  ;RIGHT SIDE OF HELICOPTER
STA VIC+6   ;SPRITE 3 (ROTORS OUT - RIGHT SIDE) X LOCATION
STA VIC+10  ;SPRITE 5 (ROTORS IN - RIGHT SIDE) X LOCATION
LDA #110
STA VIC+12  ;SPRITE 6 (MOON) X LOCATION
LDA HELIXHI ;SPRITE X LOCATION HIGH BITS
STA VIC+16

LDA #182
STA VIC+1   ;SPRITE 0 (PARKED HELICOPTER - LEFT SIDE) Y LOCATION
STA VIC+3   ;SPRITE 1 (PARKED HELICOPTER - RIGHT SIDE) Y LOCATION
LDA HELIY
LDY #5
L5 = *
STA VIC,Y   ;SPRITE 2-5 (ANIMATED HELICOPTER) Y LOCATION
INY
INY
CPY #13
BNE L5
LDA #65
STA VIC+13  ;SPRITE 6 (MOON) Y LOCATION

LDA #1      ;WHITE
STA VIC+45  ;SET SPRITE 6 COLOR
LDA #5      ;GREEN
LDY #0
L4 = *
STA VIC+39,Y ;SET SPRITE (0-6) COLOR
INY
CPY #6
BNE L4
LDA #%01110011
STA VIC+21 ;TURN ON SPRITES 0, 1, 4, 5 & 6

LDA TIME   ;SET UP 1.5-SECOND DELAY
CLC
ADC #90
STA JIFFYCLOCK
JSR WAITDELAY
RTS

; *** INITIALIZE SOUND ***
SOUNDINIT = *
LDY  #23   ;CLEAR SID REGISTERS
LDA  #0
L7   STA SID,Y
DEY
BNE  L7

LDA  #$10
STA  SID+6  ;VOICE 1 (ENGINE) SUSTAIN/RELEASE VALUE
LDA  #$21
STA  SID+4  ;VOICE 1 WAVEFORM AND GATE (ON)
LDA  #4
STA  SID+8  ;VOICE 2 (ROTORS) FREQUENCY HIGH BYTE
LDA  #$20
STA  SID+12 ;VOICE 2 ATTACK/DECAY VALUE
LDA  #$02
STA  SID+13 ;VOICE 2 SUSTAIN/RELEASE VALUE
LDA  #40
STA  SID+14 ;VOICE 3 (RING MODULATION) FREQUENCY (LOW BYTE)
LDA  #$10
STA  SID+20 ;VOICE 3 SUSTAIN/RELEASE VALUE
LDA  #$11
STA  SID+18 ;VOICE 3 WAVEFORM AND GATE (ON)
LDA  #$50
STA  SID+22 ;FILTER CUTOFF FREQUENCY (HIGH BYTE)
LDA  #7
STA  SID+23 ;FILTER SELECT & RESONANCE (FILTER VOICES 1, 2 & 3)
LDA  #$1F
STA  SID+24 ;VOLUME AND FILTER TYPE SELECT (LOW PASS)
RTS

; *** STARTING ENGINES ***
STARTUP = *
LDA SPRACTIVE
STA VIC+21 ;TURN ON ACTIVE SPRITES

LDX #80
L6 = *
LDA STARTDELAY
BEQ L6C
DEC STARTDELAY
LDA STARTDELAY
CLC
ADC TIME
STA JIFFYCLOCK
JSR WAITDELAY

L6C LDA #0
JSR GETIN ;CHECK FOR KEYPRESS
BEQ L6A
LDA #1
STA KEYPRESS
JMP L6B
L6A JSR FLIPFRAME
DEX
BNE L6
L6B = *
RTS

; *** TAXI, TAKEOFF AND CRUISE ***
ANIMATE = *
LDA KEYPRESS
BEQ L8A
JMP L14
L8A = *
DEC HELIX1
LDA HELIX1
CMP #$FF
BNE L8
LDA HELIXHI
AND #4
BEQ L9
LDA HELIXHI
AND #%11101011
STA HELIXHI
JMP L8
L9 = *
LDA #110
STA HELIX1
LDA HELIXHI
ORA #%00010100
STA HELIXHI

L8 = *
DEC HELIX2
LDA HELIX2
CMP #$FF
BNE L10
LDA HELIXHI
AND #8
BEQ L11
LDA HELIXHI
AND #%11010111
STA HELIXHI
JMP L10
L11 = *
LDA #110
STA HELIX2
LDA HELIXHI
ORA #%00101000
STA HELIXHI

L10 = *
LDA HELIX1  ;LEFT SIDE OF HELICOPTER
STA VIC+4   ;SPRITE 2 X LOCATION
STA VIC+8   ;SPRITE 4 X LOCATION
CMP #220
BNE L12
LDA #1
STA LIFTOFF
L12 = *
LDA LIFTOFF
CMP #1
BNE L13
LDX HELIY
CPX #140
BEQ L13
DEX
STX HELIY
STX VIC+5   ;SPRITE 2 Y LOCATION
STX VIC+7   ;SPRITE 3 Y LOCATION
STX VIC+9   ;SPRITE 4 Y LOCATION
STX VIC+11  ;SPRITE 5 Y LOCATION

L13 = *
LDA HELIX2  ;RIGHT SIDE OF HELICOPTER
STA VIC+6   ;SPRITE 3 X LOCATION
STA VIC+10  ;SPRITE 5 X LOCATION
LDA HELIXHI
STA VIC+16  ;SPRITE X LOCATION HIGH BITS
JSR FLIPFRAME

LDA #0
JSR GETIN ;CHECK FOR KEYPRESS
BNE L14
JMP ANIMATE
L14 = *
RTS

; *** FLIP HELICOPTER FRAME FOR ANIMATION EFFECT ***
FLIPFRAME = *
LDA SPRACTIVE
EOR #%00111100
STA SPRACTIVE
STA VIC+21 ;FLIP FRAMES
JSR SETDELAY
LDY PITCH
CPY #64
BEQ L15
INY
STY PITCH
STY SID+1
STY SID+15
L15 LDA  #$81
STA  SID+11  ;VOICE 2 WAVEFORM AND GATE (ON)
JSR WAITDELAY
LDA  #$80
STA  SID+11  ;VOICE 2 WAVEFORM AND GATE (OFF)
RTS

; *** SET UP FRAME DELAY ***
SETDELAY = *
LDA TIME
CLC
ADC #5
STA JIFFYCLOCK
RTS

; *** WAIT FOR JIFFY CLOCK ***
WAITDELAY = *
LDA TIME
CMP RADARDELAY
BNE WD2
JSR SPINRADAR
WD2 CMP JIFFYCLOCK
BNE WAITDELAY
RTS

; *** ROTATE RADAR DOME ***
SPINRADAR = *
PHA
TYA
PHA
TXA
PHA
LDX #0
LDY RADARFRAME
L18 LDA RADAR,Y
STA 8192+192,X
INY
INX
CPX #8
BNE L18

LDA RADARFRAME
CLC
ADC #8
CMP #64
BCC L19
LDA #0
L19 STA RADARFRAME

LDA TIME
CLC
ADC #15
STA RADARDELAY
PLA
TAX
PLA
TAY
PLA
RTS

; *** PREPARE TO EXIT PROGRAM ***
CLEANUP = *
LDA #0
STA SID+$18    ;TURN OFF SID
LDA #0
STA VIC+21     ;TURN OFF ALL SPRITES
JSR CLRSCR     ;CLEAR SCREEN
LDA 53272
AND #240
ORA #4
STA 53272      ;RESTORE ROM CHARACTER SET
RTS

; *** PROGRAM VARIABLES ***
HELIX1 *=*+1   ;X LOCATION OF HELICOPTER (LEFT SIDE)
HELIX2 *=*+1   ;X LOCATION OF HELICOPTER (RIGHT SIDE)
HELIXHI *=*+1  ;X LOCATION OF HELICOPTER (HIGH BITS)
HELIY *=*+1    ;Y LOCATION OF HELICOPTER
SPRACTIVE !BYTE %11001111  ;USED TO "FLIP" FRAMES FOR ANIMATION
JIFFYCLOCK *=*+1 ;USED TO KEEP TRACK OF DELAY FOR HELICOPTER ANIMATION
STARTDELAY *=*+1 ;DECREASING DELAY DURING ENGINE START
RADARDELAY *=*+1 ;USED TO KEEP TRACK OF DELAY FOR RADAR ANIMATION
LIFTOFF *=*+1  ;FLAG TO INDICATE TAKEOFF MODE
KEYPRESS *=*+1 ;FLAG TO INDICATE A KEY HAS BEEN PRESSED
PITCH *=*+1 ;ENGINE PITCH
RADARFRAME *=*+1 ;EIGHT FRAMES FOR ANIMATION (45 DEGREES PER FRAME)

; *** SPRITE DATA ***
* = 2944
!BYTE 001,192,000,000,048,000,003,255,224,252,008,031,000,028,000,000,062
!BYTE 001,000,063,000,000,063,128,000,063,255,000,063,255,000,031,187,000
!BYTE 015,255,000,007,255,000,015,255,000,050,128,000,197,000,000,000,000
!BYTE 000,000,000,000,000,000,000,000,000,000,000,000,000,000,000,000,000
!BYTE 000,000,003,128,000,128,096,000,007,255,192,248,016,063,000,056,000
!BYTE 000,124,000,255,254,000,255,157,000,187,156,128,255,159,192,255,156
!BYTE 128,255,255,000,002,128,000,002,128,000,000,000,000,000,000,000,000
!BYTE 000,000,000,000,000,000,000,000,000,000,000,000,000,000,000,000,000
!BYTE 000,255,248,000,000,008,000,000,028,000,000,062,000,000,127,255,000
!BYTE 191,255,001,061,221,003,255,255,001,063,255,000,255,255,000,001,064
!BYTE 000,001,064,000,000,000,000,000,000,000,000,000,000,000,000,000,000
!BYTE 000,000,000,000,000,000,000,000,000,031,255,000,016,000,000,056,000
!BYTE 000,124,000,000,252,000,001,252,000,255,252,000,255,252,000,221,248
!BYTE 000,255,240,000,255,224,000,255,192,000,001,064,000,000,160,000,000
!BYTE 000,000,000,000,000,000,000,000,000,000,000,000,000,000,000,000,000
!BYTE 000,000,000,000,000,000,001,000,000,000,000,015,255,000,008,000,000
!BYTE 028,000,000,062,000,000,127,255,000,191,255,001,061,221,003,255,255
!BYTE 001,063,255,000,255,255,000,001,064,000,001,064,000,000,000,000,000
!BYTE 000,000,000,000,000,000,000,000,000,000,000,000,000,000,000,000,000
!BYTE 255,240,000,000,016,000,128,056,000,000,124,000,000,252,000,001,252
!BYTE 000,255,252,000,255,252,000,221,248,000,255,240,000,255,224,000,255
!BYTE 192,000,001,064,000,000,160,000,000,000,000,000,000,000,000,000,000
!BYTE 000,000,000,000,000,000,000,000,000,000,000,000,000,000,028,000,000
!BYTE 015,000,000,015,128,000,007,192,000,007,224,000,007,224,000,007,240
!BYTE 000,007,240,000,007,240,000,007,240,000,015,240,000,015,240,000,031
!BYTE 240,000,063,224,000,127,224,001,255,192,015,255,128,007,255,000,001
!BYTE 252,000,000,000,000,000

; *** AIRPORT GRAPHICS (CBM ASCII)
SCREENDATA = *
!BYTE 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32
!BYTE 32,32,27,32,32,32,32,32,27,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32
!BYTE 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32
!BYTE 32,32,32,27,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32
!BYTE 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32
!BYTE 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,233,223,32,32,32,32,32,32,32,32,32,32,32,32
!BYTE 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,233,160,160,223,32,32,32
!BYTE 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,233,223,32,32,32,32,32,32,32,32
!BYTE 233,160,160,160,160,223,233,223,32,32,32,32,32,32,32,32,32,32,32,32,233,223,32,32,32,233,223,32,32,233,160,160
!BYTE 223,32,32,32,32,32,32,233,160,160,160,160,160,160,160,160,223,32,32,233,223,32,32,32,32,32,32,233,160,160,223,32
!BYTE 233,160,160,223,233,160,160,160,160,223,32,32,233,223,233,160,160,160,160,160,160,160,160,160,160,223,233,160,160,223,32,32
!BYTE 233,223,233,160,160,160,160,233,160,160,160,160,160,160,160,160,160,160,223,233,160,160,160,160,160,160,160,160,160,160,160,160
!BYTE 160,160,160,160,160,160,223,233,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160
!BYTE 160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,160,32,32,32,32,32,32,32,32,32
!BYTE 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,100,100,100,100,32,32,32,32,32
!BYTE 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,77
!BYTE 100,100,78,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32
!BYTE 32,32,32,32,32,32,32,32,160,160,32,32,32,32,32,32,32,32,233,160,160,160,160,105,101,32,32,32,32,32,32,32
!BYTE 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,160,160,32,32,32,32,32,32,32,233,160,160,160,160,105,32
!BYTE 116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,160,160,32,32,24,32,32,32
!BYTE 233,160,160,160,160,105,32,32,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32
!BYTE 160,160,32,32,32,32,32,32,227,227,227,227,227,32,32,78,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29
!BYTE 29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,32,160,160,160,160,160,32,78,32,32,32,32,32,32,32,32,32
!BYTE 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,160,160,160,160,160,78,32,28
!BYTE 28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,32
!BYTE 32,32,32,32,32,32,32,32,32,32,30,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28
!BYTE 28,28,28,28,28,28,28,32,32,32,32,32,29,29,29,29,29,30,32,25,32,100,32,100,32,100,32,100,32,100,32,100
!BYTE 32,100,32,100,32,100,32,100,32,100,32,100,32,100,32,32,32,32,32,32,32,32,32,32,30,32,26,32,32,32,32,32
!BYTE 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,31
!BYTE 29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,32
!BYTE 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32
!BYTE 32,32,32,32,32,32,32

COLORDATA = *
!BYTE 8,8,248,248,8,8,8,248,248,8,8,40,56,56,8,248,8,56,56,8,248,8,248,56,40,8,248,8,8,56,120,8,248
!BYTE 248,56,1,8,56,248,8,241,241,120,8,248,248,56,56,8,248,248,248,248,248,248,136,248,248,56,56,8,248,248,40,248
!BYTE 56,8,56,8,8,56,8,136,248,248,8,8,8,56,248,8,248,40,8,248,248,8,56,40,56,248,248,8,8,8,248,248
!BYTE 8,120,8,113,248,8,248,8,8,248,248,248,8,8,248,248,248,8,56,8,8,248,248,8,8,40,248,8,8,248,248,56
!BYTE 8,8,8,248,56,56,248,120,248,8,56,8,8,8,248,56,8,8,248,248,56,248,248,56,40,248,248,248,248,248,8,241
!BYTE 1,1,1,1,241,1,49,1,49,1,49,1,1,241,241,1,241,1,1,1,248,8,8,248,8,8,248,248,8,248,8,40
!BYTE 248,8,8,8,8,8,56,1,241,49,1,1,1,241,33,1,33,241,1,33,33,1,49,1,1,241,1,1,1,248,56,8
!BYTE 8,8,8,248,8,248,8,248,8,8,248,56,56,8,8,241,241,1,1,49,241,1,1,241,1,1,49,49,1,241,1,241
!BYTE 1,1,1,241,241,49,241,1,49,49,1,241,1,1,1,49,1,241,1,1,241,241,8,9,9,249,9,249,9,249,249,9
!BYTE 9,9,249,9,249,249,9,57,9,249,9,249,249,9,249,9,249,9,249,41,57,9,249,249,57,249,249,57,9,9,9,249
!BYTE 9,249,41,249,9,9,9,249,9,249,249,9,249,9,249,249,9,249,249,249,9,57,9,249,9,9,249,249,41,249,249,9
!BYTE 57,9,57,9,9,249,249,41,9,9,249,249,249,9,249,9,249,57,9,9,249,249,9,249,249,249,57,9,249,249,57,9
!BYTE 9,57,9,9,249,9,249,249,9,9,249,249,249,9,9,249,249,9,9,249,249,41,9,249,249,9,9,249,249,9,249,249
!BYTE 9,9,249,9,249,9,249,249,9,249,9,249,249,9,249,41,41,9,249,249,249,249,249,15,255,15,15,15,15,31,15,15
!BYTE 63,255,15,255,15,255,63,63,15,15,255,63,255,255,15,15,255,255,63,255,15,15,255,255,255,15,15,248,40,248,8,8
!BYTE 248,8,200,248,8,248,56,40,40,8,248,248,248,8,248,248,248,56,56,56,8,248,248,56,248,248,24,248,248,248,248,255
!BYTE 15,15,15,56,248,248,248,248,248,248,248,8,248,8,8,248,248,8,56,8,248,56,8,248,248,248,8,248,56,8,248,56
!BYTE 248,248,8,40,8,8,8,8,242,15,56,248,248,248,248,254,14,254,62,254,254,62,254,14,14,8,248,248,56,248,248,8
!BYTE 248,40,8,248,8,40,248,248,8,8,248,248,248,56,8,248,255,2,8,8,40,8,248,254,62,14,254,254,254,254,254,62
!BYTE 254,8,248,8,248,56,8,40,8,248,8,40,8,248,8,248,248,8,248,56,8,8,40,248,2,255,248,8,8,8,248,14
!BYTE 14,14,14,62,62,254,254,254,62,8,120,56,248,248,8,8,8,56,8,8,8,56,8,8,8,248,248,8,248,248,8,248
!BYTE 15,2,40,8,8,8,200,14,14,14,14,14,62,14,62,254,246,246,246,38,246,246,246,246,6,246,54,246,6,246,6,246
!BYTE 54,6,6,246,246,134,246,38,54,246,6,6,54,6,246,14,14,14,62,14,14,14,14,8,56,56,8,8,8,248,8,8
!BYTE 248,248,56,248,8,8,8,248,8,8,40,8,8,24,56,40,8,8,8,248,248,8,8,14,14,254,14,14,14,254,54,6
!BYTE 6,6,6,246,54,6,6,246,6,6,246,54,6,6,54,246,246,6,6,6,6,6,246,6,246,6,246,6,54,246,6,241
!BYTE 1,33,33,1,241,1,1,49,1,33,1,1,241,1,241,49,241,1,1,241,49,1,1,241,33,1,241,1,49,1,241,241
!BYTE 1,49,1,241,1,1,1,241,1,49,1,33,1,49,241,1,241,1,1,252,15,15,255,15,255,15,15,15,15,15,15,15
!BYTE 15,63,15,15,15,15,15,255,15,15,15,255,15,15,255,15,15,15,15,63,15,255,255,255,241,241,252,248,248,248,248,248
!BYTE 8,248,8,8,248,8,248,8,248,40,8,8,248,56,56,8,40,248,72,56,248,8,8,241,241,1,1,1,1,241,1,241
!BYTE 1,241,1,33,49,33,49,1,241,1,1,33,1,49,33,1,241,1,241,1,241,241,241,1,33,1,241,1,241,1,241,248
!BYTE 248,88,56,248,8,8,248,8,248,56,8,8,8,8,8,248,248,56,8,8,248,248,8,248,40,8,248,248,8,248,248,8
!BYTE 248,8,248,40,248,248,248

; *** CUSTOM CHARACTERS ***
CUSTCHARS = *
!BYTE 0,98,115,81,73,79,70,0 ;ROTATED "2"
!BYTE 0,3,3,121,125,7,3,0 ;ROTATED "7"
!BYTE 0,0,0,0,0,0,0,1 ;STAR
!BYTE 34,0,0,0,0,0,0,0 ;RUNWAY LIGHTS - TOP
!BYTE 0,0,0,0,0,0,0,34 ;RUNWAY LIGHTS - BOTTOM
!BYTE 1,2,4,8,16,32,64,128 ;DIAGONAL LIGHTS
!BYTE 1,2,4,8,16,32,64,162 ;DIAGONAL CORNER LIGHTS

RADAR = *
!BYTE 254,254,238,254,254,16,16,56
!BYTE 124,124,100,124,124,16,16,56
!BYTE 56,56,36,56,56,16,16,56
!BYTE 124,124,124,124,124,16,16,56
!BYTE 254,254,254,254,254,16,16,56
!BYTE 124,124,124,124,124,16,16,56
!BYTE 56,56,72,56,56,16,16,56
!BYTE 124,124,76,124,124,16,16,56
